@@ -3,4 +3,4 @@ package main
 import _ "embed"
 
 //go:embed examples/demo.tape
-var DemoTape []byte
+var demoTape []byte
