@@ -1,3 +1,6 @@
+// Package neofetch is an example package.
+//
+//nolint:unused
 package neofetch
 
 import (
@@ -41,17 +44,3 @@ func clamp(v, low, high int) int {
 	}
 	return min(high, max(low, v))
 }
-
-func min(a, b int) int {
-	if a < b {
-		return a
-	}
-	return b
-}
-
-func max(a, b int) int {
-	if a > b {
-		return a
-	}
-	return b
-}
