@@ -1,3 +1,4 @@
+// Package parser provides a parser for the VHS Tape language.
 package parser
 
 import (
@@ -36,8 +37,8 @@ var CommandTypes = []CommandType{ //nolint: deadcode
 	token.ESCAPE,
 	token.ILLEGAL,
 	token.LEFT,
-	token.PAGEUP,
-	token.PAGEDOWN,
+	token.PAGE_UP,
+	token.PAGE_DOWN,
 	token.RIGHT,
 	token.SET,
 	token.OUTPUT,
@@ -65,6 +66,7 @@ type Command struct {
 	Type    CommandType
 	Options string
 	Args    string
+	Source  string
 }
 
 // String returns the string representation of the command.
@@ -123,7 +125,7 @@ func (p *Parser) Parse() []Command {
 			p.nextToken()
 			continue
 		}
-		cmds = append(cmds, p.parseCommand())
+		cmds = append(cmds, p.parseCommand()...)
 		p.nextToken()
 	}
 
@@ -131,7 +133,7 @@ func (p *Parser) Parse() []Command {
 }
 
 // parseCommand parses a command.
-func (p *Parser) parseCommand() Command {
+func (p *Parser) parseCommand() []Command {
 	switch p.cur.Type {
 	case token.SPACE,
 		token.BACKSPACE,
@@ -144,44 +146,44 @@ func (p *Parser) parseCommand() Command {
 		token.LEFT,
 		token.RIGHT,
 		token.UP,
-		token.PAGEUP,
-		token.PAGEDOWN:
-		return p.parseKeypress(p.cur.Type)
+		token.PAGE_UP,
+		token.PAGE_DOWN:
+		return []Command{p.parseKeypress(p.cur.Type)}
 	case token.SET:
-		return p.parseSet()
+		return []Command{p.parseSet()}
 	case token.OUTPUT:
-		return p.parseOutput()
+		return []Command{p.parseOutput()}
 	case token.SLEEP:
-		return p.parseSleep()
+		return []Command{p.parseSleep()}
 	case token.TYPE:
-		return p.parseType()
+		return []Command{p.parseType()}
 	case token.CTRL:
-		return p.parseCtrl()
+		return []Command{p.parseCtrl()}
 	case token.ALT:
-		return p.parseAlt()
+		return []Command{p.parseAlt()}
 	case token.SHIFT:
-		return p.parseShift()
+		return []Command{p.parseShift()}
 	case token.HIDE:
-		return p.parseHide()
+		return []Command{p.parseHide()}
 	case token.REQUIRE:
-		return p.parseRequire()
+		return []Command{p.parseRequire()}
 	case token.SHOW:
-		return p.parseShow()
+		return []Command{p.parseShow()}
 	case token.WAIT:
-		return p.parseWait()
+		return []Command{p.parseWait()}
 	case token.SOURCE:
 		return p.parseSource()
 	case token.SCREENSHOT:
-		return p.parseScreenshot()
+		return []Command{p.parseScreenshot()}
 	case token.COPY:
-		return p.parseCopy()
+		return []Command{p.parseCopy()}
 	case token.PASTE:
-		return p.parsePaste()
+		return []Command{p.parsePaste()}
 	case token.ENV:
-		return p.parseEnv()
+		return []Command{p.parseEnv()}
 	default:
 		p.errors = append(p.errors, NewError(p.cur, "Invalid command: "+p.cur.Literal))
-		return Command{Type: token.ILLEGAL}
+		return []Command{{Type: token.ILLEGAL}}
 	}
 }
 
@@ -256,7 +258,7 @@ func (p *Parser) parseRepeat() string {
 
 // parseTime parses a time argument.
 //
-// <number>[ms]
+//	<number>[ms]
 func (p *Parser) parseTime() string {
 	var t string
 
@@ -282,10 +284,10 @@ func (p *Parser) parseTime() string {
 // parseCtrl parses a control command.
 // A control command takes one or multiples characters and/or modifiers to type while ctrl is held down.
 //
-// Ctrl[+Alt][+Shift]+<char>
-// E.g:
-// Ctrl+Shift+O
-// Ctrl+Alt+Shift+P
+//	Ctrl[+Alt][+Shift]+<char>
+//	E.g:
+//	Ctrl+Shift+O
+//	Ctrl+Alt+Shift+P
 func (p *Parser) parseCtrl() Command {
 	var args []string
 
@@ -315,6 +317,12 @@ func (p *Parser) parseCtrl() Command {
 		case peek.Type == token.ENTER,
 			peek.Type == token.SPACE,
 			peek.Type == token.BACKSPACE,
+			peek.Type == token.MINUS,
+			peek.Type == token.AT,
+			peek.Type == token.LEFT_BRACKET,
+			peek.Type == token.RIGHT_BRACKET,
+			peek.Type == token.CARET,
+			peek.Type == token.BACKSLASH,
 			peek.Type == token.STRING && len(peek.Literal) == 1:
 			args = append(args, peek.Literal)
 		default:
@@ -338,12 +346,14 @@ func (p *Parser) parseCtrl() Command {
 // parseAlt parses an alt command.
 // An alt command takes a character to type while the modifier is held down.
 //
-// Alt+<character>
+//	Alt+<character>
 func (p *Parser) parseAlt() Command {
 	if p.peek.Type == token.PLUS {
 		p.nextToken()
 		if p.peek.Type == token.STRING ||
 			p.peek.Type == token.ENTER ||
+			p.peek.Type == token.LEFT_BRACKET ||
+			p.peek.Type == token.RIGHT_BRACKET ||
 			p.peek.Type == token.TAB {
 			c := p.peek.Literal
 			p.nextToken()
@@ -358,16 +368,18 @@ func (p *Parser) parseAlt() Command {
 // parseShift parses a shift command.
 // A shift command takes one character and types while shift is held down.
 //
-// Shift+<char>
-// E.g.
-// Shift+A
-// Shift+Tab
-// Shift+Enter
+//	Shift+<char>
+//	E.g.
+//	Shift+A
+//	Shift+Tab
+//	Shift+Enter
 func (p *Parser) parseShift() Command {
 	if p.peek.Type == token.PLUS {
 		p.nextToken()
 		if p.peek.Type == token.STRING ||
 			p.peek.Type == token.ENTER ||
+			p.peek.Type == token.LEFT_BRACKET ||
+			p.peek.Type == token.RIGHT_BRACKET ||
 			p.peek.Type == token.TAB {
 			c := p.peek.Literal
 			p.nextToken()
@@ -382,7 +394,7 @@ func (p *Parser) parseShift() Command {
 // parseKeypress parses a repeatable and time adjustable keypress command.
 // A keypress command takes an optional typing speed and optional count.
 //
-// Key[@<time>] [count]
+//	Key[@<time>] [count]
 func (p *Parser) parseKeypress(ct token.Type) Command {
 	cmd := Command{Type: CommandType(ct)}
 	cmd.Options = p.parseSpeed()
@@ -393,7 +405,7 @@ func (p *Parser) parseKeypress(ct token.Type) Command {
 // parseOutput parses an output command.
 // An output command takes a file path to which to output.
 //
-// Output <path>
+//	Output <path>
 func (p *Parser) parseOutput() Command {
 	cmd := Command{Type: token.OUTPUT}
 
@@ -420,7 +432,7 @@ func (p *Parser) parseOutput() Command {
 // parseSet parses a set command.
 // A set command takes a setting name and a value.
 //
-// Set <setting> <value>
+//	Set <setting> <value>
 func (p *Parser) parseSet() Command {
 	cmd := Command{Type: token.SET}
 
@@ -515,7 +527,7 @@ func (p *Parser) parseSet() Command {
 // parseSleep parses a sleep command.
 // A sleep command takes a time for how long to sleep.
 //
-// Sleep <time>
+//	Sleep <time>
 func (p *Parser) parseSleep() Command {
 	cmd := Command{Type: token.SLEEP}
 	cmd.Args = p.parseTime()
@@ -524,8 +536,7 @@ func (p *Parser) parseSleep() Command {
 
 // parseHide parses a Hide command.
 //
-// Hide
-// ...
+//	Hide
 func (p *Parser) parseHide() Command {
 	cmd := Command{Type: token.HIDE}
 	return cmd
@@ -533,8 +544,7 @@ func (p *Parser) parseHide() Command {
 
 // parseRequire parses a Require command.
 //
-// ...
-// Require
+//	Require
 func (p *Parser) parseRequire() Command {
 	cmd := Command{Type: token.REQUIRE}
 
@@ -550,8 +560,7 @@ func (p *Parser) parseRequire() Command {
 
 // parseShow parses a Show command.
 //
-// ...
-// Show
+//	Show
 func (p *Parser) parseShow() Command {
 	cmd := Command{Type: token.SHOW}
 	return cmd
@@ -560,7 +569,7 @@ func (p *Parser) parseShow() Command {
 // parseType parses a type command.
 // A type command takes a string to type.
 //
-// Type "string"
+//	Type "string"
 func (p *Parser) parseType() Command {
 	cmd := Command{Type: token.TYPE}
 
@@ -593,7 +602,7 @@ func (p *Parser) parseType() Command {
 // parseCopy parses a copy command
 // A copy command takes a string to the clipboard
 //
-// Copy "string"
+//	Copy "string"
 func (p *Parser) parseCopy() Command {
 	cmd := Command{Type: token.COPY}
 
@@ -622,7 +631,7 @@ func (p *Parser) parseCopy() Command {
 // parsePaste parses paste command
 // Paste Command the string from the clipboard buffer.
 //
-// Paste
+//	Paste
 func (p *Parser) parsePaste() Command {
 	cmd := Command{Type: token.PASTE}
 	return cmd
@@ -631,7 +640,7 @@ func (p *Parser) parsePaste() Command {
 // parseEnv parses Env command
 // Env command takes in a key-value pair which is set.
 //
-// Env key "value"
+//	Env key "value"
 func (p *Parser) parseEnv() Command {
 	cmd := Command{Type: token.ENV}
 
@@ -651,14 +660,14 @@ func (p *Parser) parseEnv() Command {
 // parseSource parses source command.
 // Source command takes a tape path to include in current tape.
 //
-// Source <path>
-func (p *Parser) parseSource() Command {
+//	Source <path>
+func (p *Parser) parseSource() []Command {
 	cmd := Command{Type: token.SOURCE}
 
 	if p.peek.Type != token.STRING {
 		p.errors = append(p.errors, NewError(p.cur, "Expected path after Source"))
 		p.nextToken()
-		return cmd
+		return []Command{cmd}
 	}
 
 	srcPath := p.peek.Literal
@@ -668,7 +677,7 @@ func (p *Parser) parseSource() Command {
 	if ext != ".tape" {
 		p.errors = append(p.errors, NewError(p.peek, "Expected file with .tape extension"))
 		p.nextToken()
-		return cmd
+		return []Command{cmd}
 	}
 
 	// Check if tape exist
@@ -676,7 +685,7 @@ func (p *Parser) parseSource() Command {
 		notFoundErr := fmt.Sprintf("File %s not found", srcPath)
 		p.errors = append(p.errors, NewError(p.peek, notFoundErr))
 		p.nextToken()
-		return cmd
+		return []Command{cmd}
 	}
 
 	// Check if source tape contains nested Source command
@@ -685,7 +694,7 @@ func (p *Parser) parseSource() Command {
 		readErr := fmt.Sprintf("Unable to read file: %s", srcPath)
 		p.errors = append(p.errors, NewError(p.peek, readErr))
 		p.nextToken()
-		return cmd
+		return []Command{cmd}
 	}
 
 	srcTape := string(d)
@@ -694,7 +703,7 @@ func (p *Parser) parseSource() Command {
 		readErr := fmt.Sprintf("Source tape: %s is empty", srcPath)
 		p.errors = append(p.errors, NewError(p.peek, readErr))
 		p.nextToken()
-		return cmd
+		return []Command{cmd}
 	}
 
 	srcLexer := lexer.New(srcTape)
@@ -706,7 +715,7 @@ func (p *Parser) parseSource() Command {
 		if cmd.Type == token.SOURCE {
 			p.errors = append(p.errors, NewError(p.peek, "Nested Source detected"))
 			p.nextToken()
-			return cmd
+			return []Command{cmd}
 		}
 	}
 
@@ -715,18 +724,27 @@ func (p *Parser) parseSource() Command {
 	if len(srcErrors) > 0 {
 		p.errors = append(p.errors, NewError(p.peek, fmt.Sprintf("%s has %d errors", srcPath, len(srcErrors))))
 		p.nextToken()
-		return cmd
+		return []Command{cmd}
+	}
+
+	filtered := make([]Command, 0)
+	for _, srcCmd := range srcCmds {
+		// Output have to be avoid in order to not overwrite output of the original tape.
+		if srcCmd.Type == token.SOURCE ||
+			srcCmd.Type == token.OUTPUT {
+			continue
+		}
+		filtered = append(filtered, srcCmd)
 	}
 
-	cmd.Args = p.peek.Literal
 	p.nextToken()
-	return cmd
+	return filtered
 }
 
 // parseScreenshot parses screenshot command.
 // Screenshot command takes a file path for storing screenshot.
 //
-// Screenshot <path>
+//	Screenshot <path>
 func (p *Parser) parseScreenshot() Command {
 	cmd := Command{Type: token.SCREENSHOT}
 
@@ -764,7 +782,7 @@ func (p *Parser) nextToken() {
 	p.peek = p.l.NextToken()
 }
 
-// Check if a given windowbar type is valid
+// Check if a given windowbar type is valid.
 func isValidWindowBar(w string) bool {
 	return w == "" ||
 		w == "Colorful" || w == "ColorfulRight" ||
