@@ -160,9 +160,9 @@ func TestParseTapeFile(t *testing.T) {
 		{Type: token.DOWN, Options: "", Args: "1"},
 		{Type: token.DOWN, Options: "", Args: "2"},
 		{Type: token.DOWN, Options: "1s", Args: "3"},
-		{Type: token.PAGEDOWN, Options: "", Args: "1"},
-		{Type: token.PAGEDOWN, Options: "", Args: "2"},
-		{Type: token.PAGEDOWN, Options: "1s", Args: "3"},
+		{Type: token.PAGE_DOWN, Options: "", Args: "1"},
+		{Type: token.PAGE_DOWN, Options: "", Args: "2"},
+		{Type: token.PAGE_DOWN, Options: "1s", Args: "3"},
 		{Type: token.ENTER, Options: "", Args: "1"},
 		{Type: token.ENTER, Options: "", Args: "2"},
 		{Type: token.ENTER, Options: "1s", Args: "3"},
@@ -181,9 +181,9 @@ func TestParseTapeFile(t *testing.T) {
 		{Type: token.UP, Options: "", Args: "1"},
 		{Type: token.UP, Options: "", Args: "2"},
 		{Type: token.UP, Options: "1s", Args: "3"},
-		{Type: token.PAGEUP, Options: "", Args: "1"},
-		{Type: token.PAGEUP, Options: "", Args: "2"},
-		{Type: token.PAGEUP, Options: "1s", Args: "3"},
+		{Type: token.PAGE_UP, Options: "", Args: "1"},
+		{Type: token.PAGE_UP, Options: "", Args: "2"},
+		{Type: token.PAGE_UP, Options: "1s", Args: "3"},
 		{Type: token.DOWN, Options: "", Args: "1"},
 		{Type: token.DOWN, Options: "", Args: "2"},
 		{Type: token.DOWN, Options: "1s", Args: "3"},
@@ -302,7 +302,7 @@ func (st *parseSourceTest) run(t *testing.T) {
 	if st.writeFile {
 		err := os.WriteFile("source.tape", []byte(st.srcTape), os.ModePerm)
 		if err != nil {
-			t.Fatalf(err.Error())
+			t.Fatal(err)
 		}
 	}
 
